@@ -1,7 +1,7 @@
 package Tk::IO;
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = '3.019'; # $Id: //depot/Tk8/IO/IO.pm#19$
+$VERSION = '3.023'; # $Id: //depot/Tk8/IO/IO.pm#23$
 
 require 5.002;
 require Tk;
@@ -14,6 +14,9 @@ use base  qw(DynaLoader IO::Handle Exporter);
 
 bootstrap Tk::IO $Tk::VERSION;
 
+my %fh2obj;
+my %obj2fh;
+
 sub new
 {
  my ($package,%args) = @_;
@@ -189,12 +192,15 @@ sub TIEHANDLE
  *{$fh} = *{*$src}{IO};
  ${*$fh}{Handlers} = {};
  ${*$fh}{imode} = 0;
+$fh2obj{$src} = $fh;
+$obj2fh{$fh} = $src;
  return bless $fh,$class;
 }
 
 sub DESTROY
 {
  my $obj = shift;
+delete $fh2obj{$obj2fh{$obj}};
  $obj->CLOSE;
 }
 
@@ -224,7 +230,7 @@ sub READLINE
 
 sub READ
 {   
- return sysread($_[0],$_[1],$_[2],$_[3]);
+ return sysread($_[0],$_[1],$_[2],defined $_[3] ? $_[3] : 0);
 }
 
 sub GETC
@@ -307,7 +313,7 @@ sub fileevent
    $file = Symbol::qualify($file,(caller)[0]);
    $file = \*{$file};
   }
- my $obj = tie *$file,'Tk::IO', $file;
+ my $obj = (exists $fh2obj{$file} ? $fh2obj{$file} : tie *$file,'Tk::IO', $file);
  $obj->deleteHandler($mode);
  $obj->addHandler($mode,$cb) if ($cb);
 }
