@@ -10,18 +10,16 @@
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 
-require Tk;
 package Tk::Text; 
 use AutoLoader;
 use Carp;
 use strict;
 
 use vars qw($VERSION @ISA);
-$VERSION = '3.009'; # $Id: //depot/Tk8/Text/Text.pm#9$
+$VERSION = '3.013'; # $Id: //depot/Tk8/Text/Text.pm#13$
 
-require Tk::Clipboard;
-
-@ISA = qw(Tk::Clipboard Tk::Widget);
+use Tk qw(Ev);
+use base  qw(Tk::Clipboard Tk::Widget);
 
 Construct Tk::Widget 'Text';
 
@@ -29,8 +27,6 @@ bootstrap Tk::Text $Tk::VERSION;
 
 sub Tk_cmd { \&Tk::text }
 
-import Tk qw(Ev);
-
 sub Tk::Widget::ScrlText { shift->Scrolled('Text' => @_) }
 
 Tk::Methods("bbox","compare","debug","delete","dlineinfo","dump",
