@@ -1,7 +1,7 @@
 #
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994 Sun Microsystems, Inc.
-# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1999 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 
 # modify it under the same terms as Perl itself, subject
@@ -44,7 +44,7 @@ use Carp;
 # is created, $VERSION is checked by bootstrap
 $Tk::version     = "8.0";
 $Tk::patchLevel  = "8.0";
-$Tk::VERSION     = '800.010';
+$Tk::VERSION     = '800.013';
 $Tk::strictMotif = 0;
 
 {($Tk::library) = __FILE__ =~ /^(.*)\.pm$/;}
@@ -66,7 +66,7 @@ my $boot_time = timeofday();
 
 # This is a workround for Solaris X11 locale handling
 Preload(DynaLoader::dl_findfile('-L/usr/openwin/lib','-lX11'))
-  if (&NeedPreload && -d '/usr/openwin/lib');
+  if (NeedPreload() && -d '/usr/openwin/lib');
 
 use Tk::Submethods ('option'    =>  [qw(add get clear readfile)],
                     'clipboard' =>  [qw(clear append)]
@@ -221,8 +221,13 @@ sub SplitString
 
 sub Methods
 {
- my ($package,$file) = caller;
- $package->EnterMethods($file,@_);
+ my ($package) = caller;
+ no strict 'refs';
+ foreach my $meth (@_)
+  {
+   my $name = $meth;
+   *{$package."::$meth"} = sub { shift->WidgetMethod($name,@_) };
+  }
 }
 
 sub fileevent
@@ -231,10 +236,11 @@ sub fileevent
  goto &Tk::IO::fileevent;
 }
 
-sub messageBox {
+sub MessageBox {
+    my ($kind,%args) = @_;
     require Tk::Dialog;
-    my $parent = shift;
-    my $args = {@_};		# list to hash ref
+    my $parent = delete $args{'-parent'};
+    my $args = \%args;
 
     $args->{-bitmap} = delete $args->{-icon} if defined $args->{-icon};
     $args->{-text} = delete $args->{-message} if defined $args->{-message};
@@ -243,30 +249,26 @@ sub messageBox {
     my $type;
     if (defined($type = delete $args->{-type})) {
 	delete $args->{-type};
-	my @buttons;
-	if ($type eq 'AbortRetryIgnore') {
-	    @buttons = qw/Abort Retry Ignore/;
-	} elsif ($type eq 'OK') {
-	    @buttons = qw/OK/;
-	} elsif ($type eq 'OKCancel') {
-	    @buttons = qw/OK Cancel/;
-	} elsif ($type eq 'RetryCancel') {
-	    @buttons = qw/Retry Cancel/;
-	} elsif ($type eq 'YesNo') {
-	    @buttons = qw/Yes No/;
-	} elsif ($type eq 'YesNoCancel') {
-	    @buttons = qw/Yes No cancel/;
-	}
+	my @buttons = grep($_,map(ucfirst($_),
+                      split(/(abort|retry|ignore|yes|no|cancel|ok)/,
+                            lc($type))));
 	$args->{-buttons} = [@buttons];
 	$args->{-default_button} = delete $args->{-default} if
 	    defined $args->{-default};
 	if (not defined $args->{-default_button} and scalar(@buttons) == 1) {
 	   $args->{-default_button} = $buttons[0]; 
 	}
-	$parent->Dialog(%$args)->Show;
+	return $parent->Dialog(%$args)->Show;
     }
 } # end messageBox
 
+sub messageBox
+{
+ my ($widget,%args) = @_;
+ $args{'-type'} = (exists $args{'-type'}) ? lc($args{'-type'}) : 'ok';
+ tk_messageBox(-parent => $widget, %args);
+}
+
 sub getOpenFile
 {
  tk_getOpenFile(-parent => shift,@_);
@@ -320,12 +322,13 @@ sub ColorDialog
 
 sub FDialog
 {
- require Tk::FileSelect;
- if ($_[0] =~ /Save/)
+ require Tk::FBox;
+ my $cmd = shift;
+ if ($cmd =~ /Save/)
   {
-   push(@_,-create => 1, -verify => [qw(!-d -w)]);
+   push @_, -type => 'save';
   }
- DialogWrapper('FileSelect',@_);
+ DialogWrapper('FBox', $cmd, @_);
 }
 
 *MotifFDialog = \&FDialog;
@@ -349,14 +352,27 @@ sub catch (&)
 {
  my $sub = shift;
  eval {local $SIG{'__DIE__'}; &$sub };
+} 
+
+my $Home;
+
+sub TranslateFileName
+{
+ local $_ = shift;
+ unless (defined $Home)
+  {
+   $Home = $ENV{'HOME'} || ($ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'});
+   $Home =~ s#\\#/#g;
+   $Home .= '/' unless $Home =~ m#/$#;
+  }
+ s#~/#$Home#g;
+ # warn $_;
+ return $_;
 }
 
 1;
 
 __END__
-# provide an exit() to be exported if exit occurs
-# before a MainWindow->new()
-sub exit { CORE::exit(@_);}
 
 sub Error
 {my $w = shift;
@@ -675,4 +691,6 @@ sub lsearch
  return -1;
 }
 
+ 
+
 
