@@ -1,17 +1,27 @@
 package Tk::FileSelect;
 
 use vars qw($VERSION);
-$VERSION = '3.020'; # $Id: //depot/Tk8/Tk/FileSelect.pm#20$
+$VERSION = '3.026'; # $Id: //depot/Tk8/Tk/FileSelect.pm#26$
 
 use Tk qw(Ev);
 use strict;
 use Carp;
-@Tk::FileSelect::ISA = qw(Tk::Toplevel);
+use base qw(Tk::Toplevel);
+use Tk::widgets qw(LabEntry Button Frame Listbox Scrollbar);
 
 Construct Tk::Widget 'FileSelect';
 
 # Documentation after __END__
 
+sub import {
+    if (defined $_[1] and $_[1] eq 'as_default') {
+	local $^W = 0;
+	package Tk;
+	*FDialog      = \&Tk::FileSelect::FDialog;
+	*MotifFDialog = \&Tk::FileSelect::FDialog;
+    }
+}
+
 sub Cancel
 {
  my ($cw) = @_;
@@ -267,7 +277,8 @@ sub filter
 sub defaultextension
 {
  my ($cw,$key,$val) = @_;
- $cw->filter("*.$val");
+ $val = ".$val" if ($val !~ /^\./);
+ $cw->filter("*$val");
 }
 
 sub directory
@@ -306,7 +317,7 @@ sub reread
   {
    $w->configure('-filter', '*');
   }
- unless ($^T)
+ unless (Tk::tainting())
   {
    if (chdir($dir))
     {
@@ -469,6 +480,19 @@ sub Show
 
 }
 
+sub FDialog
+{
+ my($cmd, %args) = @_;
+ if ($cmd =~ /Save/)
+  {
+   $args{-create} = 1;
+   $args{-verify} = [qw(!-d -w)];
+  }
+ delete $args{-filetypes};
+ delete $args{-force};
+ Tk::DialogWrapper('FileSelect',$cmd, %args);
+}
+
 1;
 
 __END__
