@@ -1,4 +1,4 @@
-# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1999 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::MainWindow;
@@ -8,10 +8,10 @@ BEGIN { @MainWindow::ISA = 'Tk::MainWindow' }
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '3.023'; # $Id: //depot/Tk8/Tk/MainWindow.pm#23$
+$VERSION = '3.037'; # $Id: //depot/Tk8/Tk/MainWindow.pm#37$
 
 use Tk::CmdLine;
-require Tk;
+use Tk qw(catch);
 require Tk::Toplevel;
 
 use Carp;
@@ -60,6 +60,12 @@ sub new
  $top->InitObject(\%args);
  eval { $top->configure(%args) };
  croak "$@" if ($@);
+ if (($top->positionfrom||'') ne 'user' and ($top->sizefrom||'') ne 'user') {
+     my $geometry = $top->optionGet(qw(geometry Geometry));
+     if ($geometry) {
+	 $top->geometry($geometry);
+     }
+ }
  push(@Windows,$top);
  return $top;
 }
@@ -68,23 +74,27 @@ sub InitBindings
 {
  my $mw = shift;
  $mw->bind('all',"<Tab>","focusNext");
- $mw->bind('all',"<Shift-Tab>","focusPrev");  
+ $mw->eventAdd(qw[<<LeftTab>> <Shift-Tab>]);
+ catch {  $mw->eventAdd(qw[<<LeftTab>> <ISO_Left_Tab>]) };
+ $mw->bind('all',"<<LeftTab>>","focusPrev");  
  if ($Tk::platform eq 'unix')
   {
    $mw->eventAdd(qw[<<Cut>> <Control-Key-x> <Key-F20> <Meta-Key-w>]);
    $mw->eventAdd(qw[<<Copy>> <Control-Key-c> <Key-F16> <Control-Key-w>]);
    $mw->eventAdd(qw[<<Paste>> <Control-Key-v> <Key-F18> <Control-Key-y>]);
+   $mw->eventAdd(qw[<<Undo>> <Control-Key-z> <Key-Undo> <Key-F14>]);
   }
  else
   {
    $mw->eventAdd(qw[<<Cut>> <Control-Key-x> <Shift-Key-Delete>]);
    $mw->eventAdd(qw[<<Copy>> <Control-Key-c> <Control-Key-Insert>]);
    $mw->eventAdd(qw[<<Paste>> <Control-Key-v> <Shift-Key-Insert>]);
+   $mw->eventAdd(qw[<<Undo>> <Control-Key-z>]);
   }
 
  # FIXME - Should these move to Menubutton ? 
  my $c = ($Tk::platform eq 'unix') ? 'all' : 'Tk::Menubutton';
- $mw->bind($c,"<Alt-KeyPress>",['TraverseToMenu',Tk::Ev('A')]);
+ $mw->bind($c,"<Alt-KeyPress>",['TraverseToMenu',Tk::Ev('K')]);
  $mw->bind($c,"<F10>",'FirstMenu');
 }
 
