@@ -506,7 +506,9 @@ DoConfig(interp, tkwin, specPtr, value, widgRec)
 	    case TK_CONFIG_BITMAP: {
 		Pixmap new, old;
 
-		if (nullValue) {
+		if (nullValue || 
+		   (( specPtr->specFlags & TK_CONFIG_NULL_OK) && 
+                      !*LangString(value)))  {
 		    new = None;
 	        } else {
 		    uid = Tk_GetUid(LangString(value));
@@ -881,7 +883,7 @@ FormatConfigValue(interp, tkwin, specPtr, widgRec, freeProcPtr)
 	case TK_CONFIG_FONT: {
 	    Tk_Font tkfont = *((Tk_Font *) ptr);
 	    if (tkfont != NULL) {
-		LangSetArg(&result, LangFontArg(interp, tkfont));
+		LangSetArg(&result, LangFontArg(interp, tkfont, NULL));
 	    }
 	    break;
 	}
