@@ -5,12 +5,13 @@
  *	procedures but not exported outside the module.
  *
  * Copyright (c) 1990-1994 The Regents of the University of California.
- * Copyright (c) 1994-1996 Sun Microsystems, Inc.
+ * Copyright (c) 1994-1997 Sun Microsystems, Inc.
+ * Copyright (c) 1998 by Scriptics Corporation.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkInt.h 1.172 96/10/12 17:29:48
+ * SCCS: @(#) tkInt.h 1.6 98/08/04 12:19:22
  */
 
 #ifndef _TKINT
@@ -19,12 +20,9 @@
 #ifndef _TK
 #include "tk.h"
 #endif
-
-#ifndef _LANG
-#include "Lang.h"
-#endif
-#ifndef _TKPORT
-#include <tkPort.h>
+#ifdef BUILD_tk
+# undef TCL_STORAGE_CLASS
+# define TCL_STORAGE_CLASS DLLEXPORT
 #endif
 
 /*
@@ -34,8 +32,45 @@
 typedef struct TkColormap TkColormap;
 typedef struct TkGrabEvent TkGrabEvent;
 typedef struct Tk_PostscriptInfo Tk_PostscriptInfo;
+typedef struct TkpCursor_ *TkpCursor;
 typedef struct TkRegion_ *TkRegion;
 typedef struct TkStressedCmap TkStressedCmap;
+typedef struct TkBindInfo_ *TkBindInfo;
+
+/*
+ * Procedure types.
+ */
+
+typedef int (TkBindEvalProc) _ANSI_ARGS_((ClientData clientData,
+	Tcl_Interp *interp, XEvent *eventPtr, Tk_Window tkwin,
+	KeySym keySym));
+typedef void (TkBindFreeProc) _ANSI_ARGS_((ClientData clientData));
+typedef Window (TkClassCreateProc) _ANSI_ARGS_((Tk_Window tkwin,
+	Window parent, ClientData instanceData));
+typedef void (TkClassGeometryProc) _ANSI_ARGS_((ClientData instanceData));
+typedef void (TkClassModalProc) _ANSI_ARGS_((Tk_Window tkwin,
+	XEvent *eventPtr));
+
+
+/*
+ * Widget class procedures used to implement platform specific widget
+ * behavior.
+ */
+
+typedef struct TkClassProcs {
+    TkClassCreateProc *createProc;
+				/* Procedure to invoke when the
+                                   platform-dependent window needs to be
+                                   created. */
+    TkClassGeometryProc *geometryProc;
+				/* Procedure to invoke when the geometry of a
+				   window needs to be recalculated as a result
+				   of some change in the system. */
+    TkClassModalProc *modalProc;
+				/* Procedure to invoke after all bindings on a
+				   widget have been triggered in order to
+				   handle a modal loop. */
+} TkClassProcs;
 
 /*
  * One of the following structures is maintained for each cursor in
@@ -244,25 +279,20 @@ typedef struct TkDisplay {
      * Information used by tkFocus.c only:
      */
 
-    struct TkWindow *focusWinPtr;
-				/* Window that currently has the focus for
-				 * this display, or NULL if none. */
     struct TkWindow *implicitWinPtr;
 				/* If the focus arrived at a toplevel window
 				 * implicitly via an Enter event (rather
 				 * than via a FocusIn event), this points
 				 * to the toplevel window.  Otherwise it is
 				 * NULL. */
-    struct TkWindow *focusOnMapPtr;
-				/* This points to a toplevel window that is
-				 * supposed to receive the X input focus as
-				 * soon as it is mapped (needed to handle the
-				 * fact that X won't allow the focus on an
-				 * unmapped window).  NULL means no delayed
-				 * focus op in progress. */
-    int forceFocus;		/* Associated with focusOnMapPtr:  non-zero
-				 * means claim the focus even if some other
-				 * application currently has it. */
+    struct TkWindow *focusPtr;	/* Points to the window on this display that
+				 * should be receiving keyboard events.  When
+				 * multiple applications on the display have
+				 * the focus, this will refer to the
+				 * innermost window in the innermost
+				 * application.  This information isn't used
+				 * under Unix or Windows, but it's needed on
+				 * the Macintosh. */
 
     /*
      * Used by tkColor.c only:
@@ -293,6 +323,12 @@ typedef struct TkDisplay {
     XIM inputMethod;		/* Input method for this display */
 #endif /* TK_USE_INPUT_METHODS */
     Tcl_HashTable winTable;	/* Maps from X window ids to TkWindow ptrs. */
+
+    int refCount;		/* Reference count of how many Tk applications
+                                 * are using this display. Used to clean up
+                                 * the display when we no longer have any
+                                 * Tk applications using it.
+                                 */
 } TkDisplay;
 
 /*
@@ -371,21 +407,26 @@ typedef struct TkMainInfo {
     Tk_BindingTable bindingTable;
 				/* Used in conjunction with "bind" command
 				 * to bind events to Tcl commands. */
-    struct TkVirtualEventTable *vetPtr;
-				/* Hold definitions of virtual events. */
-    struct TkFocusInfo *focusPtr;
+    TkBindInfo bindInfo;	/* Information used by tkBind.c on a per
+				 * interpreter basis. */
+    struct TkFontInfo *fontInfoPtr;
+				/* Hold named font tables.  Used only by
+				 * tkFont.c. */
+
+    /*
+     * Information used only by tkFocus.c and tk*Embed.c:
+     */
+
+    struct TkToplevelFocusInfo *tlFocusPtr;
 				/* First in list of records containing focus
 				 * information for each top-level in the
 				 * application.  Used only by tkFocus.c. */
-    unsigned long focusSerial;	/* Serial number of last request we made to
-				 * change the focus.  Used to identify
-				 * stale focus notifications coming from the
-				 * X server. */
-    struct TkWindow *lastFocusPtr;
-				/* The most recent window that was given the
-				 * focus via "focus" command.  Used to restore
-				 * the focus when we get stale FocusIn
-				 * events. */
+    struct TkDisplayFocusInfo *displayFocusPtr;
+				/* First in list of records containing focus
+				 * information for each display that this
+				 * application has ever used.  Used only
+				 * by tkFocus.c. */
+
     struct ElArray *optionRootPtr;
 				/* Top level of option hierarchy for this
 				 * main window.  NULL means uninitialized.
@@ -398,6 +439,19 @@ typedef struct TkMainInfo {
 				 * this process. */
 } TkMainInfo;
 
+/*
+ * Tk keeps the following data structure for each of it's builtin
+ * bitmaps.  This structure is only used by tkBitmap.c and other
+ * platform specific bitmap files.
+ */
+
+typedef struct {
+    char *source;		/* Bits for bitmap. */
+    int width, height;		/* Dimensions of bitmap. */
+    int native;			/* 0 means generic (X style) bitmap,
+    				 * 1 means native style bitmap. */
+} TkPredefBitmap;
+
 /*
  * Tk keeps one of the following structures for each window.
  * Some of the information (like size and location) is a shadow
@@ -427,18 +481,20 @@ typedef struct TkWindow {
 				 * hasn't actually been created yet, or it's
 				 * been deleted. */
     struct TkWindow *childList;	/* First in list of child windows,
-				 * or NULL if no children. */
+				 * or NULL if no children.  List is in
+				 * stacking order, lowest window first.*/
     struct TkWindow *lastChildPtr;
-				/* Last in list of child windows, or NULL
-				 * if no children. */
+				/* Last in list of child windows (highest
+				 * in stacking order), or NULL if no
+				 * children. */
     struct TkWindow *parentPtr;	/* Pointer to parent window (logical
 				 * parent, not necessarily X parent).  NULL
 				 * means either this is the main window, or
 				 * the window's parent has already been
 				 * deleted. */
-    struct TkWindow *nextPtr;	/* Next in list of children with
-				 * same parent (NULL if end of
-				 * list). */
+    struct TkWindow *nextPtr;	/* Next higher sibling (in stacking order)
+				 * in list of children with same parent.  NULL
+				 * means end of list. */
     TkMainInfo *mainPtr;	/* Information shared by all windows
 				 * associated with a particular main
 				 * window.  NULL means this window is
@@ -543,10 +599,18 @@ typedef struct TkWindow {
      * Information maintained by tkWm.c for window manager communication.
      */
 
-    struct TkWmInfo *wmInfoPtr;	/* For top-level windows, points to
-				 * structure with wm-related info (see
-				 * tkWm.c).  For other windows, this
-				 * is NULL. */
+    struct TkWmInfo *wmInfoPtr;	/* For top-level windows (and also
+				 * for special Unix menubar and wrapper
+				 * windows), points to structure with
+				 * wm-related info (see tkWm.c).  For
+				 * other windows, this is NULL. */
+
+    /*
+     * Information used by widget classes.
+     */
+
+    TkClassProcs *classProcsPtr;
+    ClientData instanceData;
 
     /*
      * Platform specific information private to each port.
@@ -588,16 +652,6 @@ typedef struct TkpClipMask {
 
 extern TkDisplay *tkDisplayList;
 
-/*
- * Flags passed to TkMeasureChars:
- */
-
-#define TK_WHOLE_WORDS		 1
-#define TK_AT_LEAST_ONE		 2
-#define TK_PARTIAL_OK		 4
-#define TK_NEWLINES_NOT_SPECIAL	 8
-#define TK_IGNORE_TABS		16
-
 /*
  * Return values from TkGrabState:
  */
@@ -615,6 +669,14 @@ extern TkDisplay *tkDisplayList;
 
 #define UCHAR(c) ((unsigned char) (c))
 
+/*
+ * The following symbol is used in the mode field of FocusIn events
+ * generated by an embedded application to request the input focus from
+ * its container.
+ */
+
+#define EMBEDDED_APP_WANTS_FOCUS (NotifyNormal + 20)
+
 /*
  * Miscellaneous variables shared among Tk modules but not exported
  * to the outside world:
@@ -632,6 +694,7 @@ MOVEXT Tk_PhotoImageFormat	tkImgFmtPPM;
 extern TkMainInfo		*tkMainWindowList;
 extern Tk_Uid			tkNormalUid;
 MOVEXT Tk_ImageType		tkPhotoImageType;
+extern Tcl_HashTable		tkPredefBitmapTable;
 extern int			tkSendSerial;
 
 /*
@@ -641,6 +704,8 @@ extern int			tkSendSerial;
 
 EXTERN char *		TkAlignImageData _ANSI_ARGS_((XImage *image,
 			    int alignment, int bitOrder));
+EXTERN TkWindow *	TkAllocWindow _ANSI_ARGS_((TkDisplay *dispPtr,
+			    int screenNum, TkWindow *parentPtr));
 MOVEXT int		TkAreaToPolygon _ANSI_ARGS_((double *polyPtr,
 			    int numPoints, double *rectPtr));
 MOVEXT void		TkBezierPoints _ANSI_ARGS_((double control[],
@@ -648,6 +713,7 @@ MOVEXT void		TkBezierPoints _ANSI_ARGS_((double control[],
 MOVEXT void		TkBezierScreenPoints _ANSI_ARGS_((Tk_Canvas canvas,
 			    double control[], int numSteps,
 			    XPoint *xPointPtr));
+EXTERN void		TkBindDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkBindEventProc _ANSI_ARGS_((TkWindow *winPtr,
 			    XEvent *eventPtr));
 EXTERN void		TkBindFree _ANSI_ARGS_((TkMainInfo *mainPtr));
@@ -660,18 +726,20 @@ EXTERN void		TkClipBox _ANSI_ARGS_((TkRegion rgn,
 #endif
 EXTERN int		TkClipInit _ANSI_ARGS_((Tcl_Interp *interp,
 			    TkDisplay *dispPtr));
-EXTERN int		TkCmapStressed _ANSI_ARGS_((Tk_Window tkwin,
-			    Colormap colormap));
-EXTERN void		TkComputeTextGeometry _ANSI_ARGS_((
-			    XFontStruct *fontStructPtr, char *string,
-			    int numChars, int wrapLength, int *widthPtr,
-			    int *heightPtr));
-EXTERN void		TkConsoleCreate _ANSI_ARGS_((void));
-EXTERN int		TkConsoleInit _ANSI_ARGS_((Tcl_Interp *interp));
-EXTERN void		TkConsolePrint _ANSI_ARGS_((Tcl_Interp *interp,
-			    int devId, char *buffer, long size));
+EXTERN void		TkComputeAnchor _ANSI_ARGS_((Tk_Anchor anchor,
+			    Tk_Window tkwin, int padX, int padY,
+			    int innerWidth, int innerHeight, int *xPtr,
+			    int *yPtr));
 EXTERN int		TkCopyAndGlobalEval _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *script));
+EXTERN unsigned long	TkCreateBindingProcedure _ANSI_ARGS_((
+			    Tcl_Interp *interp, Tk_BindingTable bindingTable,
+			    ClientData object, char *eventString,
+			    TkBindEvalProc *evalProc, TkBindFreeProc *freeProc,
+			    ClientData clientData));
+EXTERN Pixmap		TkCreateBitmapFromData _ANSI_ARGS_((Display* display,
+			    Drawable d, CONST char* data,
+			    unsigned int width, unsigned int height));
 EXTERN TkCursor *	TkCreateCursorFromData _ANSI_ARGS_((Tk_Window tkwin,
 			    char *source, char *mask, int width, int height,
 			    int xHot, int yHot, XColor fg, XColor bg));
@@ -690,16 +758,12 @@ EXTERN void		TkDeleteAllImages _ANSI_ARGS_((TkMainInfo *mainPtr));
 #ifndef TkDestroyRegion
 EXTERN void		TkDestroyRegion _ANSI_ARGS_((TkRegion rgn));
 #endif
-EXTERN void		TkDisplayChars _ANSI_ARGS_((Display *display,
-			    Drawable drawable, GC gc,
-			    XFontStruct *fontStructPtr, char *string,
-			    int numChars, int x, int y, int tabOrigin,
-			    int flags));
-EXTERN void		TkDisplayText _ANSI_ARGS_((Display *display,
-			    Drawable drawable, XFontStruct *fontStructPtr,
-			    char *string, int numChars, int x, int y,
-			    int length, Tk_Justify justify, int underline,
-			    GC gc));
+EXTERN void		TkDoConfigureNotify _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN void		TkDrawInsetFocusHighlight _ANSI_ARGS_((
+			    Tk_Window tkwin, GC gc, int width,
+			    Drawable drawable, int padding));
+EXTERN void		TkEventCleanupProc _ANSI_ARGS_((
+			    ClientData clientData, Tcl_Interp *interp));
 EXTERN void		TkEventDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkFillPolygon _ANSI_ARGS_((Tk_Canvas canvas,
 			    double *coordPtr, int numPoints, Display *display,
@@ -712,10 +776,16 @@ EXTERN char *		TkFindStateString _ANSI_ARGS_((
 EXTERN void		TkFocusDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN int		TkFocusFilterEvent _ANSI_ARGS_((TkWindow *winPtr,
 			    XEvent *eventPtr));
+EXTERN TkWindow *	TkFocusKeyEvent _ANSI_ARGS_((TkWindow *winPtr,
+			    XEvent *eventPtr));
+EXTERN void		TkFontPkgInit _ANSI_ARGS_((TkMainInfo *mainPtr));
+EXTERN void		TkFontPkgFree _ANSI_ARGS_((TkMainInfo *mainPtr));
 EXTERN void		TkFreeBindingTags _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN void		TkFreeCursor _ANSI_ARGS_((TkCursor *cursorPtr));
 EXTERN void		TkFreeWindowId _ANSI_ARGS_((TkDisplay *dispPtr,
 			    Window w));
-EXTERN void		TkFreeCursor _ANSI_ARGS_((TkCursor *cursorPtr));
+EXTERN void		TkGenerateActivateEvents _ANSI_ARGS_((
+			    TkWindow *winPtr, int active));
 MOVEXT char *		TkGetBitmapData _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, char *fileName, int *widthPtr,
 			    int *heightPtr, int *hotXPtr, int *hotYPtr));
@@ -727,7 +797,10 @@ EXTERN TkCursor *	TkGetCursorByName _ANSI_ARGS_((Tcl_Interp *interp,
 EXTERN char *		TkGetDefaultScreenName _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *screenName));
 EXTERN TkDisplay *	TkGetDisplay _ANSI_ARGS_((Display *display));
-EXTERN TkWindow *	TkGetFocus _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN int		TkGetDisplayOf _ANSI_ARGS_((Tcl_Interp *interp,
+			    int objc, Tcl_Obj *CONST objv[],
+			    Tk_Window *tkwinPtr));
+EXTERN TkWindow *	TkGetFocusWin _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN int		TkGetInterpNames _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin));
 MOVEXT int		TkGetMiterPoints _ANSI_ARGS_((double p1[], double p2[],
@@ -752,6 +825,7 @@ EXTERN void		TkInOutEvents _ANSI_ARGS_((XEvent *eventPtr,
 			    TkWindow *sourcePtr, TkWindow *destPtr,
 			    int leaveType, int enterType,
 			    Tcl_QueuePosition position));
+EXTERN void		TkInstallFrameMenu _ANSI_ARGS_((Tk_Window tkwin));
 #ifndef TkIntersectRegion
 EXTERN void		TkIntersectRegion _ANSI_ARGS_((TkRegion sra,
 			    TkRegion srcb, TkRegion dr_return));
@@ -761,24 +835,63 @@ MOVEXT int		TkLineToArea _ANSI_ARGS_((double end1Ptr[2],
 			    double end2Ptr[2], double rectPtr[4]));
 MOVEXT double		TkLineToPoint _ANSI_ARGS_((double end1Ptr[2],
 			    double end2Ptr[2], double pointPtr[2]));
+EXTERN int		TkListAppend _ANSI_ARGS_((void **headPtrPtr,
+			    void *itemPtr, size_t size));
+EXTERN int		TkListDelete _ANSI_ARGS_((void **headPtrPtr,
+			    void *itemPtr, size_t size));
+EXTERN void *		TkListFind _ANSI_ARGS_((void *headPtr, void *itemPtr,
+			    size_t size));
 MOVEXT int		TkMakeBezierCurve _ANSI_ARGS_((Tk_Canvas canvas,
 			    double *pointPtr, int numPoints, int numSteps,
 			    XPoint xPoints[], double dblPoints[]));
 MOVEXT void		TkMakeBezierPostscript _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, double *pointPtr,
 			    int numPoints));
-EXTERN Window		TkMakeWindow _ANSI_ARGS_((TkWindow *winPtr,
-			    Window parent));
-EXTERN int		TkMeasureChars _ANSI_ARGS_((XFontStruct *fontStructPtr,
-			    char *source, int maxChars, int startX, int maxX,
-			    int tabOrigin, int flags, int *nextXPtr));
 EXTERN void		TkOptionClassChanged _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkOptionDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 MOVEXT int		TkOvalToArea _ANSI_ARGS_((double *ovalPtr,
 			    double *rectPtr));
 MOVEXT double		TkOvalToPoint _ANSI_ARGS_((double ovalPtr[4],
 			    double width, int filled, double pointPtr[2]));
-EXTERN int		TkPlatformInit _ANSI_ARGS_((Tcl_Interp *interp));
+EXTERN int		TkpChangeFocus _ANSI_ARGS_((TkWindow *winPtr,
+			    int force));
+EXTERN void		TkpCloseDisplay _ANSI_ARGS_((TkDisplay *dispPtr));
+EXTERN void		TkpClaimFocus _ANSI_ARGS_((TkWindow *topLevelPtr,
+			    int force));
+#ifndef TkpCmapStressed
+EXTERN int		TkpCmapStressed _ANSI_ARGS_((Tk_Window tkwin,
+			    Colormap colormap));
+#endif
+#ifndef TkpCreateNativeBitmap
+EXTERN Pixmap		TkpCreateNativeBitmap _ANSI_ARGS_((Display *display,
+			    char * source));
+#endif
+#ifndef TkpDefineNativeBitmaps
+EXTERN void		TkpDefineNativeBitmaps _ANSI_ARGS_((void));
+#endif
+EXTERN void		TkpDisplayWarning _ANSI_ARGS_((char *msg,
+			    char *title));
+EXTERN void		TkpGetAppName _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tcl_DString *name));
+EXTERN unsigned long	TkpGetMS _ANSI_ARGS_((void));
+#ifndef TkpGetNativeAppBitmap
+EXTERN Pixmap		TkpGetNativeAppBitmap _ANSI_ARGS_((Display *display,
+			    char *name, int *width, int *height));
+#endif
+EXTERN TkWindow *	TkpGetOtherWindow _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN TkWindow *	TkpGetWrapperWindow _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN int		TkpInit _ANSI_ARGS_((Tcl_Interp *interp));
+EXTERN void		TkpInitializeMenuBindings _ANSI_ARGS_((
+			    Tcl_Interp *interp, Tk_BindingTable bindingTable));
+EXTERN void		TkpMakeContainer _ANSI_ARGS_((Tk_Window tkwin));
+EXTERN void		TkpMakeMenuWindow _ANSI_ARGS_((Tk_Window tkwin,
+			    int transient));
+EXTERN Window		TkpMakeWindow _ANSI_ARGS_((TkWindow *winPtr,
+			    Window parent));
+EXTERN void		TkpMenuNotifyToplevelCreate _ANSI_ARGS_((
+			    Tcl_Interp *, char *menuName));
+EXTERN TkDisplay *	TkpOpenDisplay _ANSI_ARGS_((char *display_name));
+EXTERN void		TkPointerDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN int		TkPointerEvent _ANSI_ARGS_((XEvent *eventPtr,
 			    TkWindow *winPtr));
 MOVEXT int		TkPolygonToArea _ANSI_ARGS_((double *polyPtr,
@@ -787,6 +900,27 @@ MOVEXT double		TkPolygonToPoint _ANSI_ARGS_((double *polyPtr,
 			    int numPoints, double *pointPtr));
 EXTERN int		TkPositionInTree _ANSI_ARGS_((TkWindow *winPtr,
 			    TkWindow *treePtr));
+#ifndef TkpPrintWindowId
+EXTERN void		TkpPrintWindowId _ANSI_ARGS_((char *buf,
+			    Window window));
+#endif
+EXTERN void		TkpRedirectKeyEvent _ANSI_ARGS_((TkWindow *winPtr,
+			    XEvent *eventPtr));
+#ifndef TkpScanWindowId
+EXTERN int		TkpScanWindowId _ANSI_ARGS_((Tcl_Interp *interp,
+			    Arg string, int *idPtr));
+#endif
+EXTERN void		TkpSetCapture _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN void		TkpSetCursor _ANSI_ARGS_((TkpCursor cursor));
+EXTERN void		TkpSetMainMenubar _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tk_Window tkwin, char *menuName));
+#ifndef TkpSync
+EXTERN void		TkpSync _ANSI_ARGS_((Display *display));
+#endif
+EXTERN int		TkpTestembedCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		TkpUseWindow _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tk_Window tkwin, Arg string));
 #ifndef TkPutImage
 EXTERN void		TkPutImage _ANSI_ARGS_((unsigned long *colors,
 			    int ncolors, Display* display, Drawable d,
@@ -794,13 +928,23 @@ EXTERN void		TkPutImage _ANSI_ARGS_((unsigned long *colors,
 			    int dest_x, int dest_y, unsigned int width,
 			    unsigned int height));
 #endif
+EXTERN int		TkpWindowWasRecentlyDeleted _ANSI_ARGS_((Window win,
+			    TkDisplay *dispPtr));
+EXTERN void		TkpWmSetState _ANSI_ARGS_((TkWindow *winPtr,
+			    int state));
+EXTERN void		TkQueueEventForAllChildren _ANSI_ARGS_((
+			    TkWindow *winPtr, XEvent *eventPtr));
+EXTERN int		TkReadBitmapFile _ANSI_ARGS_((Display* display,
+			    Drawable d, CONST char* filename,
+			    unsigned int* width_return,
+			    unsigned int* height_return,
+			    Pixmap* bitmap_return,
+			    int* x_hot_return, int* y_hot_return));
 #ifndef TkRectInRegion
 EXTERN int		TkRectInRegion _ANSI_ARGS_((TkRegion rgn,
 			    int x, int y, unsigned int width,
 			    unsigned int height));
 #endif
-EXTERN void		TkQueueEventForAllChildren _ANSI_ARGS_((
-			    Tk_Window tkwin, XEvent *eventPtr));
 EXTERN int		TkScrollWindow _ANSI_ARGS_((Tk_Window tkwin, GC gc,
 			    int x, int y, int width, int height, int dx,
 			    int dy, TkRegion damageRgn));
@@ -808,6 +952,9 @@ EXTERN void		TkSelDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkSelEventProc _ANSI_ARGS_((Tk_Window tkwin,
 			    XEvent *eventPtr));
 EXTERN void		TkSelInit _ANSI_ARGS_((Tk_Window tkwin));
+EXTERN void		TkSelPropProc _ANSI_ARGS_((XEvent *eventPtr));
+EXTERN void		TkSetClassProcs _ANSI_ARGS_((Tk_Window tkwin,
+			    TkClassProcs *procs, ClientData instanceData));
 #ifndef TkSetPixmapColormap
 EXTERN void		TkSetPixmapColormap _ANSI_ARGS_((Pixmap pixmap,
 			    Colormap colormap));
@@ -816,16 +963,13 @@ EXTERN void		TkSetPixmapColormap _ANSI_ARGS_((Pixmap pixmap,
 EXTERN void		TkSetRegion _ANSI_ARGS_((Display* display, GC gc,
 			    TkRegion rgn));
 #endif
-EXTERN void		TkSelPropProc _ANSI_ARGS_((XEvent *eventPtr));
+EXTERN void		TkSetWindowMenuBar _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tk_Window tkwin, Arg oldMenuName, 
+			    Arg menuName));
+EXTERN KeySym		TkStringToKeysym _ANSI_ARGS_((char *name));
 MOVEXT int		TkThickPolyLineToArea _ANSI_ARGS_((double *coordPtr,
 			    int numPoints, double width, int capStyle,
 			    int joinStyle, double *rectPtr));
-EXTERN KeySym		TkStringToKeysym _ANSI_ARGS_((char *name));
-EXTERN void		TkUnderlineChars _ANSI_ARGS_((Display *display,
-			    Drawable drawable, GC gc,
-			    XFontStruct *fontStructPtr, char *string,
-			    int x, int y, int tabOrigin, int flags,
-			    int firstChar, int lastChar));
 #ifndef TkUnionRectWithRegion
 EXTERN void		TkUnionRectWithRegion _ANSI_ARGS_((XRectangle* rect,
 			    TkRegion src, TkRegion dr_return));
@@ -833,6 +977,7 @@ EXTERN void		TkUnionRectWithRegion _ANSI_ARGS_((XRectangle* rect,
 EXTERN void		TkWmAddToColormapWindows _ANSI_ARGS_((
 			    TkWindow *winPtr));
 EXTERN void		TkWmDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
+EXTERN TkWindow *	TkWmFocusToplevel _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkWmMapWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkWmNewWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkWmProtocolEventProc _ANSI_ARGS_((TkWindow *winPtr,
@@ -852,4 +997,7 @@ EXTERN int		TkXFileProc _ANSI_ARGS_((ClientData clientData,
 EXTERN int		TkUnsupported1Cmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int argc, char **argv));
 
+# undef TCL_STORAGE_CLASS
+# define TCL_STORAGE_CLASS DLLIMPORT
+
 #endif  /* _TKINT */
