@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkRectOval.c,v 1.2 1998/09/14 18:23:16 stanton Exp $
+ * SCCS: @(#) tkRectOval.c 1.40 96/05/03 10:52:21
  */
 
 #include "tkPort.h"
@@ -25,20 +25,14 @@
 typedef struct RectOvalItem  {
     Tk_Item header;		/* Generic stuff that's the same for all
 				 * types.  MUST BE FIRST IN STRUCTURE. */
-    Tk_Outline outline;		/* Outline structure */
     double bbox[4];		/* Coordinates of bounding box for rectangle
 				 * or oval (x1, y1, x2, y2).  Item includes
 				 * x1 and x2 but not y1 and y2. */
-    Tk_Tile fillTile;		/* Tile for filling rectangle/oval. */
-    Tk_Tile activeFillTile;	/* Tile for filling rectangle/oval if state is active. */
-    Tk_Tile disabledFillTile;	/* Tile for filling rectangle/oval if state is disabled. */
-    Tk_TSOffset tsoffset;
+    int width;			/* Width of outline. */
+    XColor *outlineColor;	/* Color for outline. */
     XColor *fillColor;		/* Color for filling rectangle/oval. */
-    XColor *activeFillColor;	/* Color for filling rectangle/oval if state is active. */
-    XColor *disabledFillColor;	/* Color for filling rectangle/oval if state is disabled. */
     Pixmap fillStipple;		/* Stipple bitmap for filling item. */
-    Pixmap activeFillStipple;	/* Stipple bitmap for filling item if state is active. */
-    Pixmap disabledFillStipple;	/* Stipple bitmap for filling item if state is disabled. */
+    GC outlineGC;		/* Graphics context for outline. */
     GC fillGC;			/* Graphics context for filling item. */
 } RectOvalItem;
 
@@ -46,117 +40,21 @@ typedef struct RectOvalItem  {
  * Information used for parsing configuration specs:
  */
 
-static Tk_CustomOption stateOption = {
-    Tk_StateParseProc,
-    Tk_StatePrintProc, (ClientData) 2
-};
-static Tk_CustomOption tagsOption = {
-    Tk_CanvasTagsParseProc,
+static Tk_CustomOption tagsOption = {Tk_CanvasTagsParseProc,
     Tk_CanvasTagsPrintProc, (ClientData) NULL
 };
-static Tk_CustomOption dashOption = {
-    Tk_CanvasDashParseProc,
-    Tk_CanvasDashPrintProc, (ClientData) NULL
-};
-static Tk_CustomOption tileOption = {
-    Tk_TileParseProc,
-    Tk_TilePrintProc, (ClientData) NULL
-};
-static Tk_CustomOption offsetOption = {
-    Tk_OffsetParseProc,
-    Tk_OffsetPrintProc, (ClientData) TK_OFFSET_RELATIVE
-};
-static Tk_CustomOption pixelOption = {
-    Tk_PixelParseProc,
-    Tk_PixelPrintProc, (ClientData) NULL
-};
 
 static Tk_ConfigSpec configSpecs[] = {
-    {TK_CONFIG_CUSTOM, "-activedash", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.activeDash),
-	TK_CONFIG_NULL_OK, &dashOption},
-    {TK_CONFIG_COLOR, "-activefill", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, activeFillColor),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_COLOR, "-activeoutline", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.activeColor),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_BITMAP, "-activeoutlinestipple", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.activeStipple),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-activeoutlinetile", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.activeTile),
-	TK_CONFIG_NULL_OK, &tileOption},
-    {TK_CONFIG_BITMAP, "-activestipple", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, activeFillStipple),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-activetile", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, activeFillTile),
-	TK_CONFIG_NULL_OK, &tileOption},
-    {TK_CONFIG_CUSTOM, "-activewidth", (char *) NULL, (char *) NULL,
-	"0.0", Tk_Offset(RectOvalItem, outline.activeWidth),
-	TK_CONFIG_DONT_SET_DEFAULT, &pixelOption},
-    {TK_CONFIG_CUSTOM, "-dash", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.dash),
-	TK_CONFIG_NULL_OK, &dashOption},
-    {TK_CONFIG_PIXELS, "-dashoffset", (char *) NULL, (char *) NULL,
-	"0", Tk_Offset(RectOvalItem, outline.offset),
-	TK_CONFIG_DONT_SET_DEFAULT},
-    {TK_CONFIG_CUSTOM, "-disableddash", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.disabledDash),
-	TK_CONFIG_NULL_OK, &dashOption},
-    {TK_CONFIG_COLOR, "-disabledfill", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, disabledFillColor),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_COLOR, "-disabledoutline", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.disabledColor),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_BITMAP, "-disabledoutlinestipple", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.disabledStipple),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-disabledoutlinetile", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.disabledTile),
-	TK_CONFIG_NULL_OK, &tileOption},
-    {TK_CONFIG_BITMAP, "-disabledstipple", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, disabledFillStipple),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-disabledtile", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, disabledFillTile),
-	TK_CONFIG_NULL_OK, &tileOption},
-    {TK_CONFIG_PIXELS, "-disabledwidth", (char *) NULL, (char *) NULL,
-	"0.0", Tk_Offset(RectOvalItem, outline.disabledWidth),
-	TK_CONFIG_DONT_SET_DEFAULT, &pixelOption},
     {TK_CONFIG_COLOR, "-fill", (char *) NULL, (char *) NULL,
 	(char *) NULL, Tk_Offset(RectOvalItem, fillColor), TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-offset", (char *) NULL, (char *) NULL,
-	"0,0", Tk_Offset(RectOvalItem, tsoffset),
-	TK_CONFIG_DONT_SET_DEFAULT, &offsetOption},
     {TK_CONFIG_COLOR, "-outline", (char *) NULL, (char *) NULL,
-	"black", Tk_Offset(RectOvalItem, outline.color), TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-outlineoffset", (char *) NULL, (char *) NULL,
-	"0,0", Tk_Offset(RectOvalItem, outline.tsoffset),
-	TK_CONFIG_DONT_SET_DEFAULT, &offsetOption},
-    {TK_CONFIG_BITMAP, "-outlinestipple", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.stipple),
-	TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-outlinetile", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, outline.tile),
-	TK_CONFIG_NULL_OK, &tileOption},
-    {TK_CONFIG_CUSTOM, "-state", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(Tk_Item, state),TK_CONFIG_NULL_OK,
-	&stateOption},
+	"black", Tk_Offset(RectOvalItem, outlineColor), TK_CONFIG_NULL_OK},
     {TK_CONFIG_BITMAP, "-stipple", (char *) NULL, (char *) NULL,
 	(char *) NULL, Tk_Offset(RectOvalItem, fillStipple), TK_CONFIG_NULL_OK},
     {TK_CONFIG_CUSTOM, "-tags", (char *) NULL, (char *) NULL,
 	(char *) NULL, 0, TK_CONFIG_NULL_OK, &tagsOption},
-    {TK_CONFIG_CUSTOM, "-tile", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(RectOvalItem, fillTile),
-	TK_CONFIG_NULL_OK, &tileOption},
-    {TK_CONFIG_CALLBACK, "-updatecommand", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(Tk_Item, updateCmd), TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-width", (char *) NULL, (char *) NULL,
-	"1.0", Tk_Offset(RectOvalItem, outline.width),
-	TK_CONFIG_DONT_SET_DEFAULT, &pixelOption},
+    {TK_CONFIG_PIXELS, "-width", (char *) NULL, (char *) NULL,
+	"1", Tk_Offset(RectOvalItem, width), TK_CONFIG_DONT_SET_DEFAULT},
     {TK_CONFIG_END, (char *) NULL, (char *) NULL, (char *) NULL,
 	(char *) NULL, 0, 0}
 };
@@ -211,7 +109,7 @@ Tk_ItemType tkRectangleType = {
     RectOvalCoords,			/* coordProc */
     DeleteRectOval,			/* deleteProc */
     DisplayRectOval,			/* displayProc */
-    TK_ITEM_VISITOR_SUPPORT|TK_CONFIG_OBJS,/* flags */
+    0,					/* alwaysRedraw */
     RectToPoint,			/* pointProc */
     RectToArea,				/* areaProc */
     RectOvalToPostscript,		/* postscriptProc */
@@ -222,11 +120,7 @@ Tk_ItemType tkRectangleType = {
     (Tk_ItemSelectionProc *) NULL,	/* selectionProc */
     (Tk_ItemInsertProc *) NULL,		/* insertProc */
     (Tk_ItemDCharsProc *) NULL,		/* dTextProc */
-    (Tk_ItemType *) NULL,		/* nextPtr */
-    (Tk_ItemBboxProc *) ComputeRectOvalBbox,/* bboxProc */
-    Tk_Offset(Tk_VisitorType, visitRectangle), /* acceptProc */
-    (Tk_ItemGetCoordProc *) NULL,	/* getCoordPtr */
-    (Tk_ItemSetCoordProc *) NULL	/* setCoordPtr */
+    (Tk_ItemType *) NULL		/* nextPtr */
 };
 
 Tk_ItemType tkOvalType = {
@@ -238,7 +132,7 @@ Tk_ItemType tkOvalType = {
     RectOvalCoords,			/* coordProc */
     DeleteRectOval,			/* deleteProc */
     DisplayRectOval,			/* displayProc */
-    TK_ITEM_VISITOR_SUPPORT|TK_CONFIG_OBJS,/* flags */
+    0,					/* alwaysRedraw */
     OvalToPoint,			/* pointProc */
     OvalToArea,				/* areaProc */
     RectOvalToPostscript,		/* postscriptProc */
@@ -249,11 +143,7 @@ Tk_ItemType tkOvalType = {
     (Tk_ItemSelectionProc *) NULL,	/* selectionProc */
     (Tk_ItemInsertProc *) NULL,		/* insertProc */
     (Tk_ItemDCharsProc *) NULL,		/* dTextProc */
-    (Tk_ItemType *) NULL,		/* nextPtr */
-    (Tk_ItemBboxProc *) ComputeRectOvalBbox,/* bboxProc */
-    Tk_Offset(Tk_VisitorType, visitOval), /* acceptProc */
-    (Tk_ItemGetCoordProc *) NULL,	/* getCoordPtr */
-    (Tk_ItemSetCoordProc *) NULL	/* setCoordPtr */
+    (Tk_ItemType *) NULL		/* nextPtr */
 };
 
 /*
@@ -286,21 +176,8 @@ CreateRectOval(interp, canvas, itemPtr, argc, argv)
     char **argv;			/* Arguments describing rectangle. */
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
-    int i;
-                                                     
-    if (argc==1) {
-	i = 1;
-    } else {
-	char *arg = Tcl_GetStringFromObj(args[1], NULL);
-	if ((argc>1) && (arg[0] == '-')
-		&& (arg[1] >= 'a') && (arg[1] <= 'z')) {
-	    i = 1;
-	} else {
-	    i = 4;
-	}
-    }
 
-    if (argc < i) {
+    if (argc < 4) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"",
 		Tk_PathName(Tk_CanvasTkwin(canvas)), " create ",
 		itemPtr->typePtr->name, " x1 y1 x2 y2 ?options?\"",
@@ -313,36 +190,34 @@ CreateRectOval(interp, canvas, itemPtr, argc, argv)
      * up after errors during the the remainder of this procedure.
      */
 
-    Tk_CreateOutline(&(rectOvalPtr->outline));
-    rectOvalPtr->fillTile = NULL;
-    rectOvalPtr->activeFillTile = NULL;
-    rectOvalPtr->disabledFillTile = NULL;
-    rectOvalPtr->tsoffset.flags = 0;
-    rectOvalPtr->tsoffset.xoffset = 0;
-    rectOvalPtr->tsoffset.yoffset = 0;
+    rectOvalPtr->width = 1;
+    rectOvalPtr->outlineColor = NULL;
     rectOvalPtr->fillColor = NULL;
-    rectOvalPtr->activeFillColor = NULL;
-    rectOvalPtr->disabledFillColor = NULL;
     rectOvalPtr->fillStipple = None;
-    rectOvalPtr->activeFillStipple = None;
-    rectOvalPtr->disabledFillStipple = None;
+    rectOvalPtr->outlineGC = None;
     rectOvalPtr->fillGC = None;
 
     /*
      * Process the arguments to fill in the item record.
      */
 
-    if ((RectOvalCoords(interp, canvas, itemPtr, i, argv) != TCL_OK)) {
-	goto error;
-    }
-    if (ConfigureRectOval(interp, canvas, itemPtr, argc-i, argv+i, 0)
-	    == TCL_OK) {
-	return TCL_OK;
+    if ((Tk_CanvasGetCoord(interp, canvas, argv[0],
+		&rectOvalPtr->bbox[0]) != TCL_OK)
+	    || (Tk_CanvasGetCoord(interp, canvas, argv[1],
+		&rectOvalPtr->bbox[1]) != TCL_OK)
+	    || (Tk_CanvasGetCoord(interp, canvas, argv[2],
+		    &rectOvalPtr->bbox[2]) != TCL_OK)
+	    || (Tk_CanvasGetCoord(interp, canvas, argv[3],
+		    &rectOvalPtr->bbox[3]) != TCL_OK)) {
+	return TCL_ERROR;
     }
 
-    error:
-    DeleteRectOval(canvas, itemPtr, Tk_Display(Tk_CanvasTkwin(canvas)));
-    return TCL_ERROR;
+    if (ConfigureRectOval(interp, canvas, itemPtr, argc-4, argv+4, 0)
+	    != TCL_OK) {
+	DeleteRectOval(canvas, itemPtr, Tk_Display(Tk_CanvasTkwin(canvas)));
+	return TCL_ERROR;
+    }
+    return TCL_OK;
 }
 
 /*
@@ -370,50 +245,34 @@ RectOvalCoords(interp, canvas, itemPtr, argc, argv)
     Tk_Item *itemPtr;			/* Item whose coordinates are to be
 					 * read or modified. */
     int argc;				/* Number of coordinates supplied in
-					 * args. */
-    Arg *args;				/* Array of coordinates: x1, y1,
+					 * argv. */
+    char **argv;			/* Array of coordinates: x1, y1,
 					 * x2, y2, ... */
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
-    char c0[TCL_DOUBLE_SPACE];
+    char c0[TCL_DOUBLE_SPACE], c1[TCL_DOUBLE_SPACE];
+    char c2[TCL_DOUBLE_SPACE], c3[TCL_DOUBLE_SPACE];
 
     if (argc == 0) {
-	Tcl_Obj *obj = Tcl_NewObj();
-	Tcl_Obj *subobj = Tcl_NewDoubleObj(rectOvalPtr->bbox[0]);
-	Tcl_ListObjAppendElement(interp, obj, subobj);
-	subobj = Tcl_NewDoubleObj(rectOvalPtr->bbox[1]);
-	Tcl_ListObjAppendElement(interp, obj, subobj);
-	subobj = Tcl_NewDoubleObj(rectOvalPtr->bbox[2]);
-	Tcl_ListObjAppendElement(interp, obj, subobj);
-	subobj = Tcl_NewDoubleObj(rectOvalPtr->bbox[3]);
-	Tcl_ListObjAppendElement(interp, obj, subobj);
-	Tcl_SetObjResult(interp, obj);
-    } else if ((argc == 1)||(argc == 4)) {
- 	if (argc==1) {
-	    if (Tcl_ListObjGetElements(interp, args[0], &argc, &args) != TCL_OK) {
-		return TCL_ERROR;
-	    } else if (argc != 4) {
-		sprintf(c0,"%d",argc);
-		Tcl_AppendResult(interp, "wrong # coordinates: expected 4, got ",
-		c0, (char *) NULL);
-		return TCL_ERROR;
-	    }
-	}
-	if ((Tk_CanvasGetCoordFromObj(interp, canvas, args[0],
- 		    &rectOvalPtr->bbox[0]) != TCL_OK)
-		|| (Tk_CanvasGetCoordFromObj(interp, canvas, args[1],
+	Tcl_DoubleResults(interp, 4, 1, 
+                          rectOvalPtr->bbox[0],  rectOvalPtr->bbox[1], 
+                          rectOvalPtr->bbox[2],  rectOvalPtr->bbox[3]);
+    } else if (argc == 4) {
+	if ((Tk_CanvasGetCoord(interp, canvas, argv[0],
+		    &rectOvalPtr->bbox[0]) != TCL_OK)
+		|| (Tk_CanvasGetCoord(interp, canvas, argv[1],
 		    &rectOvalPtr->bbox[1]) != TCL_OK)
-		|| (Tk_CanvasGetCoordFromObj(interp, canvas, args[2],
+		|| (Tk_CanvasGetCoord(interp, canvas, argv[2],
 			&rectOvalPtr->bbox[2]) != TCL_OK)
-		|| (Tk_CanvasGetCoordFromObj(interp, canvas, args[3],
+		|| (Tk_CanvasGetCoord(interp, canvas, argv[3],
 			&rectOvalPtr->bbox[3]) != TCL_OK)) {
 	    return TCL_ERROR;
 	}
 	ComputeRectOvalBbox(canvas, rectOvalPtr);
     } else {
-	sprintf(c0,"%d",argc);
-	Tcl_AppendResult(interp, "wrong # coordinates: expected 0 or 4, got ",
-	c0, (char *) NULL);
+	sprintf(interp->result,
+		"wrong # coordinates: expected 0 or 4, got %d",
+		argc);
 	return TCL_ERROR;
     }
     return TCL_OK;
@@ -453,119 +312,41 @@ ConfigureRectOval(interp, canvas, itemPtr, argc, argv, flags)
     GC newGC;
     unsigned long mask;
     Tk_Window tkwin;
-    Tk_Tile tile;
-    Tk_TSOffset *tsoffset;
-    XColor *color;
-    Pixmap stipple;
-    Tk_State state;
-    Pixmap pixmap;
 
     tkwin = Tk_CanvasTkwin(canvas);
-
     if (Tk_ConfigureWidget(interp, tkwin, configSpecs, argc, argv,
-	    (char *) rectOvalPtr, flags|TK_CONFIG_OBJS) != TCL_OK) {
+	    (char *) rectOvalPtr, flags) != TCL_OK) {
 	return TCL_ERROR;
     }
 
-    state = itemPtr->state;
-
     /*
      * A few of the options require additional processing, such as
      * graphics contexts.
      */
 
-    if (rectOvalPtr->outline.activeWidth > rectOvalPtr->outline.width ||
-	    rectOvalPtr->outline.activeDash.number > 0 ||
-	    rectOvalPtr->outline.activeTile != NULL ||
-	    rectOvalPtr->outline.activeColor != NULL ||
-	    rectOvalPtr->outline.activeStipple != None ||
-	    rectOvalPtr->activeFillTile != NULL ||
-	    rectOvalPtr->activeFillColor != NULL ||
-	    rectOvalPtr->activeFillStipple != None) {
-	itemPtr->redraw_flags |= TK_ITEM_STATE_DEPENDANT;
+    if (rectOvalPtr->width < 1) {
+	rectOvalPtr->width = 1;
+    }
+    if (rectOvalPtr->outlineColor == NULL) {
+	newGC = None;
     } else {
-	itemPtr->redraw_flags &= ~TK_ITEM_STATE_DEPENDANT;
-    }
-
-    tsoffset = &rectOvalPtr->outline.tsoffset;
-    flags = tsoffset->flags;
-    if (flags & TK_OFFSET_LEFT) {
-	tsoffset->xoffset = (int) (rectOvalPtr->bbox[0] + 0.5);
-    } else if (flags & TK_OFFSET_CENTER) {
-	tsoffset->xoffset = (int) ((rectOvalPtr->bbox[0]+rectOvalPtr->bbox[2]+1)/2);
-    } else if (flags & TK_OFFSET_RIGHT) {
-	tsoffset->xoffset = (int) (rectOvalPtr->bbox[2] + 0.5);
-    }
-    if (flags & TK_OFFSET_TOP) {
-	tsoffset->yoffset = (int) (rectOvalPtr->bbox[1] + 0.5);
-    } else if (flags & TK_OFFSET_MIDDLE) {
-	tsoffset->yoffset = (int) ((rectOvalPtr->bbox[1]+rectOvalPtr->bbox[3]+1)/2);
-    } else if (flags & TK_OFFSET_BOTTOM) {
-	tsoffset->yoffset = (int) (rectOvalPtr->bbox[2] + 0.5);
-    }
-
-    mask = Tk_ConfigOutlineGC(&gcValues, canvas, itemPtr,
-	     &(rectOvalPtr->outline));
-    if (mask) {
+	gcValues.foreground = rectOvalPtr->outlineColor->pixel;
 	gcValues.cap_style = CapProjecting;
-	mask |= GCCapStyle;
+	gcValues.line_width = rectOvalPtr->width;
+	mask = GCForeground|GCCapStyle|GCLineWidth;
 	newGC = Tk_GetGC(tkwin, mask, &gcValues);
-    } else {
-	newGC = None;
     }
-    if (rectOvalPtr->outline.gc != None) {
-	Tk_FreeGC(Tk_Display(tkwin), rectOvalPtr->outline.gc);
+    if (rectOvalPtr->outlineGC != None) {
+	Tk_FreeGC(Tk_Display(tkwin), rectOvalPtr->outlineGC);
     }
-    rectOvalPtr->outline.gc = newGC;
+    rectOvalPtr->outlineGC = newGC;
 
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-    if (state==TK_STATE_HIDDEN) {
-	ComputeRectOvalBbox(canvas, rectOvalPtr);
-	return TCL_OK;
-    }
-
-    tile = rectOvalPtr->fillTile;
-    color = rectOvalPtr->fillColor;
-    stipple = rectOvalPtr->fillStipple;
-    if (((TkCanvas *)canvas)->currentItemPtr == itemPtr) {
-	if (rectOvalPtr->activeFillTile!=NULL) {
-	    tile = rectOvalPtr->activeFillTile;
-	}
-	if (rectOvalPtr->activeFillColor!=NULL) {
-	    color = rectOvalPtr->activeFillColor;
-	}
-	if (rectOvalPtr->activeFillStipple!=None) {
-	    stipple = rectOvalPtr->activeFillStipple;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (rectOvalPtr->disabledFillTile!=NULL) {
-	    tile = rectOvalPtr->disabledFillTile;
-	}
-	if (rectOvalPtr->disabledFillColor!=NULL) {
-	    color = rectOvalPtr->disabledFillColor;
-	}
-	if (rectOvalPtr->disabledFillStipple!=None) {
-	    stipple = rectOvalPtr->disabledFillStipple;
-	}
-    }
-
-    Tk_SetTileCanvasItem(rectOvalPtr->fillTile, canvas, (Tk_Item *) NULL);
-    Tk_SetTileCanvasItem(rectOvalPtr->activeFillTile, canvas, (Tk_Item *) NULL);
-    Tk_SetTileCanvasItem(rectOvalPtr->disabledFillTile, canvas, (Tk_Item *) NULL);
-    Tk_SetTileCanvasItem(tile, canvas, itemPtr);
-
-    if ((pixmap = Tk_PixmapOfTile(tile)) != None) {
-	gcValues.fill_style = FillTiled;
-	gcValues.tile = pixmap;
-	newGC = Tk_GetGC(tkwin, GCTile|GCFillStyle, &gcValues);
-    } else if (color == NULL) {
+    if (rectOvalPtr->fillColor == NULL) {
 	newGC = None;
     } else {
-	gcValues.foreground = color->pixel;
-	if (stipple != None) {
-	    gcValues.stipple = stipple;
+	gcValues.foreground = rectOvalPtr->fillColor->pixel;
+	if (rectOvalPtr->fillStipple != None) {
+	    gcValues.stipple = rectOvalPtr->fillStipple;
 	    gcValues.fill_style = FillStippled;
 	    mask = GCForeground|GCStipple|GCFillStyle;
 	} else {
@@ -577,24 +358,6 @@ ConfigureRectOval(interp, canvas, itemPtr, argc, argv, flags)
 	Tk_FreeGC(Tk_Display(tkwin), rectOvalPtr->fillGC);
     }
     rectOvalPtr->fillGC = newGC;
-
-    tsoffset = &rectOvalPtr->tsoffset;
-    flags = tsoffset->flags;
-    if (flags & TK_OFFSET_LEFT) {
-	tsoffset->xoffset = (int) (rectOvalPtr->bbox[0] + 0.5);
-    } else if (flags & TK_OFFSET_CENTER) {
-	tsoffset->xoffset = (int) ((rectOvalPtr->bbox[0]+rectOvalPtr->bbox[2]+1)/2);
-    } else if (flags & TK_OFFSET_RIGHT) {
-	tsoffset->xoffset = (int) (rectOvalPtr->bbox[2] + 0.5);
-    }
-    if (flags & TK_OFFSET_TOP) {
-	tsoffset->yoffset = (int) (rectOvalPtr->bbox[1] + 0.5);
-    } else if (flags & TK_OFFSET_MIDDLE) {
-	tsoffset->yoffset = (int) ((rectOvalPtr->bbox[1]+rectOvalPtr->bbox[3]+1)/2);
-    } else if (flags & TK_OFFSET_BOTTOM) {
-	tsoffset->yoffset = (int) (rectOvalPtr->bbox[3] + 0.5);
-    }
-
     ComputeRectOvalBbox(canvas, rectOvalPtr);
 
     return TCL_OK;
@@ -626,33 +389,17 @@ DeleteRectOval(canvas, itemPtr, display)
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
 
-    Tk_DeleteOutline(display, &(rectOvalPtr->outline));
-    if (rectOvalPtr->fillTile != NULL) {
-	Tk_FreeTile(rectOvalPtr->fillTile);
-    }
-    if (rectOvalPtr->activeFillTile != NULL) {
-	Tk_FreeTile(rectOvalPtr->activeFillTile);
-    }
-    if (rectOvalPtr->disabledFillTile != NULL) {
-	Tk_FreeTile(rectOvalPtr->disabledFillTile);
+    if (rectOvalPtr->outlineColor != NULL) {
+	Tk_FreeColor(rectOvalPtr->outlineColor);
     }
     if (rectOvalPtr->fillColor != NULL) {
 	Tk_FreeColor(rectOvalPtr->fillColor);
     }
-    if (rectOvalPtr->activeFillColor != NULL) {
-	Tk_FreeColor(rectOvalPtr->activeFillColor);
-    }
-    if (rectOvalPtr->disabledFillColor != NULL) {
-	Tk_FreeColor(rectOvalPtr->disabledFillColor);
-    }
     if (rectOvalPtr->fillStipple != None) {
 	Tk_FreeBitmap(display, rectOvalPtr->fillStipple);
     }
-    if (rectOvalPtr->activeFillStipple != None) {
-	Tk_FreeBitmap(display, rectOvalPtr->activeFillStipple);
-    }
-    if (rectOvalPtr->disabledFillStipple != None) {
-	Tk_FreeBitmap(display, rectOvalPtr->disabledFillStipple);
+    if (rectOvalPtr->outlineGC != None) {
+	Tk_FreeGC(display, rectOvalPtr->outlineGC);
     }
     if (rectOvalPtr->fillGC != None) {
 	Tk_FreeGC(display, rectOvalPtr->fillGC);
@@ -686,28 +433,7 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
 					 * recomputed. */
 {
     int bloat, tmp;
-    double dtmp, width;
-    Tk_State state = rectOvalPtr->header.state;
-
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-
-    width = rectOvalPtr->outline.width;
-    if (state==TK_STATE_HIDDEN) {
-	rectOvalPtr->header.x1 = rectOvalPtr->header.y1 =
-	rectOvalPtr->header.x2 = rectOvalPtr->header.y2 = -1;
-	return;
-    }
-    if (((TkCanvas *)canvas)->currentItemPtr == (Tk_Item *)rectOvalPtr) {
-	if (rectOvalPtr->outline.activeWidth>width) {
-	    width = rectOvalPtr->outline.activeWidth;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (rectOvalPtr->outline.disabledWidth>0) {
-	    width = rectOvalPtr->outline.disabledWidth;
-	}
-    }
+    double dtmp;
 
     /*
      * Make sure that the first coordinates are the lowest ones.
@@ -726,10 +452,10 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
 	rectOvalPtr->bbox[0] = tmp;
     }
 
-    if (rectOvalPtr->outline.gc == None) {
+    if (rectOvalPtr->outlineColor == NULL) {
 	bloat = 0;
     } else {
-	bloat = (int) (width+1)/2;
+	bloat = (rectOvalPtr->width+1)/2;
     }
 
     /*
@@ -749,13 +475,13 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
 	dtmp = rectOvalPtr->bbox[0] + 1;
     }
     tmp = (int) ((dtmp >= 0) ? dtmp + .5 : dtmp - .5);
-    rectOvalPtr->header.x2 = tmp + bloat + 1;
+    rectOvalPtr->header.x2 = tmp + bloat;
     dtmp = rectOvalPtr->bbox[3];
     if (dtmp < (rectOvalPtr->bbox[1] + 1)) {
 	dtmp = rectOvalPtr->bbox[1] + 1;
     }
     tmp = (int) ((dtmp >= 0) ? dtmp + .5 : dtmp - .5);
-    rectOvalPtr->header.y2 = tmp + bloat + 1;
+    rectOvalPtr->header.y2 = tmp + bloat;
 }
 
 /*
@@ -788,9 +514,6 @@ DisplayRectOval(canvas, itemPtr, display, drawable, x, y, width, height)
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
     short x1, y1, x2, y2;
-    Tk_Tile fillTile;
-    Pixmap fillStipple;
-    Tk_State state = itemPtr->state;
 
     /*
      * Compute the screen coordinates of the bounding box for the item.
@@ -816,59 +539,9 @@ DisplayRectOval(canvas, itemPtr, display, drawable, x, y, width, height)
      * read-only.
      */
 
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-    fillTile = rectOvalPtr->fillTile;
-    fillStipple = rectOvalPtr->fillStipple;
-    if (((TkCanvas *)canvas)->currentItemPtr == (Tk_Item *)rectOvalPtr) {
-	if (rectOvalPtr->activeFillTile!=NULL) {
-	    fillTile = rectOvalPtr->activeFillTile;
-	}
-	if (rectOvalPtr->activeFillStipple!=None) {
-	    fillStipple = rectOvalPtr->activeFillStipple;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (rectOvalPtr->disabledFillTile!=NULL) {
-	    fillTile = rectOvalPtr->disabledFillTile;
-	}
-	if (rectOvalPtr->disabledFillStipple!=None) {
-	    fillStipple = rectOvalPtr->disabledFillStipple;
-	}
-    }
-
     if (rectOvalPtr->fillGC != None) {
-	if ((fillTile != NULL) || (fillStipple != None)) {
-	    Tk_TSOffset *tsoffset;
-	    int w=0; int h=0;
-	    tsoffset = &rectOvalPtr->tsoffset;
-	    if (tsoffset) {
-		int flags = tsoffset->flags;
-		if (flags & (TK_OFFSET_CENTER|TK_OFFSET_MIDDLE)) {
-		    if (fillTile != NULL) {
-			Tk_SizeOfTile(fillTile, &w, &h);
-		    } else {
-			Tk_SizeOfBitmap(display, fillStipple, &w, &h);
-		    }
-		    if (flags & TK_OFFSET_CENTER) {
-			w /= 2;
-		    } else {
-			w = 0;
-		    }
-		    if (flags & TK_OFFSET_MIDDLE) {
-			h /= 2;
-		    } else {
-			h = 0;
-		    }
-		}
-		tsoffset->xoffset -= w;
-		tsoffset->yoffset -= h;
-	    }
-	    Tk_CanvasSetOffset(canvas, rectOvalPtr->fillGC, tsoffset);
-	    if (tsoffset) {
-		tsoffset->xoffset += w;
-		tsoffset->yoffset += h;
-	    }
+	if (rectOvalPtr->fillStipple != None) {
+	    Tk_CanvasSetStippleOrigin(canvas, rectOvalPtr->fillGC);
 	}
 	if (rectOvalPtr->header.typePtr == &tkRectangleType) {
 	    XFillRectangle(display, drawable, rectOvalPtr->fillGC,
@@ -878,20 +551,18 @@ DisplayRectOval(canvas, itemPtr, display, drawable, x, y, width, height)
 		    x1, y1, (unsigned) (x2-x1), (unsigned) (y2-y1),
 		    0, 360*64);
 	}
-	if ((fillTile != NULL) || (fillStipple != None)) {
+	if (rectOvalPtr->fillStipple != None) {
 	    XSetTSOrigin(display, rectOvalPtr->fillGC, 0, 0);
 	}
     }
-    if (rectOvalPtr->outline.gc != None) {
-	Tk_ChangeOutlineGC(canvas, itemPtr, &(rectOvalPtr->outline));
+    if (rectOvalPtr->outlineGC != None) {
 	if (rectOvalPtr->header.typePtr == &tkRectangleType) {
-	    XDrawRectangle(display, drawable, rectOvalPtr->outline.gc,
+	    XDrawRectangle(display, drawable, rectOvalPtr->outlineGC,
 		    x1, y1, (unsigned) (x2-x1), (unsigned) (y2-y1));
 	} else {
-	    XDrawArc(display, drawable, rectOvalPtr->outline.gc,
+	    XDrawArc(display, drawable, rectOvalPtr->outlineGC,
 		    x1, y1, (unsigned) (x2-x1), (unsigned) (y2-y1), 0, 360*64);
 	}
-	Tk_ResetOutlineGC(canvas, itemPtr, &(rectOvalPtr->outline));
     }
 }
 
@@ -927,23 +598,6 @@ RectToPoint(canvas, itemPtr, pointPtr)
 {
     RectOvalItem *rectPtr = (RectOvalItem *) itemPtr;
     double xDiff, yDiff, x1, y1, x2, y2, inc, tmp;
-    double width;
-    Tk_State state = itemPtr->state;
-
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-
-    width = rectPtr->outline.width;
-    if (((TkCanvas *)canvas)->currentItemPtr == itemPtr) {
-	if (rectPtr->outline.activeWidth>width) {
-	    width = rectPtr->outline.activeWidth;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (rectPtr->outline.disabledWidth>0) {
-	    width = rectPtr->outline.disabledWidth;
-	}
-    }
 
     /*
      * Generate a new larger rectangle that includes the border
@@ -954,8 +608,8 @@ RectToPoint(canvas, itemPtr, pointPtr)
     y1 = rectPtr->bbox[1];
     x2 = rectPtr->bbox[2];
     y2 = rectPtr->bbox[3];
-    if (rectPtr->outline.gc != None) {
-	inc = width/2.0;
+    if (rectPtr->outlineGC != None) {
+	inc = rectPtr->width/2.0;
 	x1 -= inc;
 	y1 -= inc;
 	x2 += inc;
@@ -971,7 +625,7 @@ RectToPoint(canvas, itemPtr, pointPtr)
 
     if ((pointPtr[0] >= x1) && (pointPtr[0] < x2)
 		&& (pointPtr[1] >= y1) && (pointPtr[1] < y2)) {
-	if ((rectPtr->fillGC != None) || (rectPtr->outline.gc == None)) {
+	if ((rectPtr->fillGC != None) || (rectPtr->outlineGC == None)) {
 	    return 0.0;
 	}
 	xDiff = pointPtr[0] - x1;
@@ -987,7 +641,7 @@ RectToPoint(canvas, itemPtr, pointPtr)
 	if (yDiff < xDiff) {
 	    xDiff = yDiff;
 	}
-	xDiff -= width;
+	xDiff -= rectPtr->width;
 	if (xDiff < 0.0) {
 	    return 0.0;
 	}
@@ -1050,26 +704,10 @@ OvalToPoint(canvas, itemPtr, pointPtr)
     RectOvalItem *ovalPtr = (RectOvalItem *) itemPtr;
     double width;
     int filled;
-    Tk_State state = itemPtr->state;
-
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-
-    width = (double) ovalPtr->outline.width;
-    if (((TkCanvas *)canvas)->currentItemPtr == itemPtr) {
-	if (ovalPtr->outline.activeWidth>width) {
-	    width = (double) ovalPtr->outline.activeWidth;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (ovalPtr->outline.disabledWidth>0) {
-	    width = (double) ovalPtr->outline.disabledWidth;
-	}
-    }
-
 
+    width = ovalPtr->width;
     filled = ovalPtr->fillGC != None;
-    if (ovalPtr->outline.gc == None) {
+    if (ovalPtr->outlineGC == None) {
 	width = 0.0;
 	filled = 1;
     }
@@ -1107,26 +745,9 @@ RectToArea(canvas, itemPtr, areaPtr)
 {
     RectOvalItem *rectPtr = (RectOvalItem *) itemPtr;
     double halfWidth;
-    double width;
-    Tk_State state = itemPtr->state;
 
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-
-    width = rectPtr->outline.width;
-    if (((TkCanvas *)canvas)->currentItemPtr == itemPtr) {
-	if (rectPtr->outline.activeWidth>width) {
-	    width = rectPtr->outline.activeWidth;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (rectPtr->outline.disabledWidth>0) {
-	    width = rectPtr->outline.disabledWidth;
-	}
-    }
-
-    halfWidth = width/2.0;
-    if (rectPtr->outline.gc == None) {
+    halfWidth = rectPtr->width/2.0;
+    if (rectPtr->outlineGC == None) {
 	halfWidth = 0.0;
     }
 
@@ -1136,7 +757,7 @@ RectToArea(canvas, itemPtr, areaPtr)
 	    || (areaPtr[1] >= (rectPtr->bbox[3] + halfWidth))) {
 	return -1;
     }
-    if ((rectPtr->fillGC == None) && (rectPtr->outline.gc != None)
+    if ((rectPtr->fillGC == None) && (rectPtr->outlineGC != None)
 	    && (areaPtr[0] >= (rectPtr->bbox[0] + halfWidth))
 	    && (areaPtr[1] >= (rectPtr->bbox[1] + halfWidth))
 	    && (areaPtr[2] <= (rectPtr->bbox[2] - halfWidth))
@@ -1184,30 +805,13 @@ OvalToArea(canvas, itemPtr, areaPtr)
     RectOvalItem *ovalPtr = (RectOvalItem *) itemPtr;
     double oval[4], halfWidth;
     int result;
-    double width;
-    Tk_State state = itemPtr->state;
-
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-
-    width = ovalPtr->outline.width;
-    if (((TkCanvas *)canvas)->currentItemPtr == itemPtr) {
-	if (ovalPtr->outline.activeWidth>width) {
-	    width = ovalPtr->outline.activeWidth;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (ovalPtr->outline.disabledWidth>0) {
-	    width = ovalPtr->outline.disabledWidth;
-	}
-    }
 
     /*
      * Expand the oval to include the width of the outline, if any.
      */
 
-    halfWidth = width/2.0;
-    if (ovalPtr->outline.gc == None) {
+    halfWidth = ovalPtr->width/2.0;
+    if (ovalPtr->outlineGC == None) {
 	halfWidth = 0.0;
     }
     oval[0] = ovalPtr->bbox[0] - halfWidth;
@@ -1224,9 +828,9 @@ OvalToArea(canvas, itemPtr, areaPtr)
      * unfilled center, in which case we should return "outside".
      */
 
-    if ((result == 0) && (ovalPtr->outline.gc != None)
+    if ((result == 0) && (ovalPtr->outlineGC != None)
 	    && (ovalPtr->fillGC == None)) {
-	double centerX, centerY, height;
+	double centerX, centerY, width, height;
 	double xDelta1, yDelta1, xDelta2, yDelta2;
 
 	centerX = (ovalPtr->bbox[0] + ovalPtr->bbox[2])/2.0;
@@ -1355,15 +959,9 @@ RectOvalToPostscript(interp, canvas, itemPtr, prepass)
 					 * collect font information;  0 means
 					 * final Postscript is being created. */
 {
-    char pathCmd[500];
+    char pathCmd[500], string[100];
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
     double y1, y2;
-    Tk_Tile tile;
-    XColor *color;
-    Tk_Tile fillTile;
-    XColor *fillColor;
-    Pixmap fillStipple;
-    Tk_State state = itemPtr->state;
 
     y1 = Tk_CanvasPsY(canvas, rectOvalPtr->bbox[1]);
     y2 = Tk_CanvasPsY(canvas, rectOvalPtr->bbox[3]);
@@ -1386,65 +984,23 @@ RectOvalToPostscript(interp, canvas, itemPtr, prepass)
 		(rectOvalPtr->bbox[2] - rectOvalPtr->bbox[0])/2, (y1 - y2)/2);
     }
 
-    if(state == TK_STATE_NULL) {
-	state = ((TkCanvas *)canvas)->canvas_state;
-    }
-    tile = rectOvalPtr->outline.tile;
-    color = rectOvalPtr->outline.color;
-    fillTile = rectOvalPtr->fillTile;
-    fillColor = rectOvalPtr->fillColor;
-    fillStipple = rectOvalPtr->fillStipple;
-    if (((TkCanvas *)canvas)->currentItemPtr == itemPtr) {
-	if (rectOvalPtr->outline.activeTile!=NULL) {
-	    tile = rectOvalPtr->outline.activeTile;
-	}
-	if (rectOvalPtr->outline.activeColor!=NULL) {
-	    color = rectOvalPtr->outline.activeColor;
-	}
-	if (rectOvalPtr->activeFillTile!=NULL) {
-	    fillTile = rectOvalPtr->activeFillTile;
-	}
-	if (rectOvalPtr->activeFillColor!=NULL) {
-	    fillColor = rectOvalPtr->activeFillColor;
-	}
-	if (rectOvalPtr->activeFillStipple!=None) {
-	    fillStipple = rectOvalPtr->activeFillStipple;
-	}
-    } else if (state==TK_STATE_DISABLED) {
-	if (rectOvalPtr->outline.disabledTile!=NULL) {
-	    tile = rectOvalPtr->outline.disabledTile;
-	}
-	if (rectOvalPtr->outline.disabledColor!=NULL) {
-	    color = rectOvalPtr->outline.disabledColor;
-	}
-	if (rectOvalPtr->disabledFillTile!=NULL) {
-	    fillTile = rectOvalPtr->disabledFillTile;
-	}
-	if (rectOvalPtr->disabledFillColor!=NULL) {
-	    fillColor = rectOvalPtr->disabledFillColor;
-	}
-	if (rectOvalPtr->disabledFillStipple!=None) {
-	    fillStipple = rectOvalPtr->disabledFillStipple;
-	}
-    }
-
     /*
      * First draw the filled area of the rectangle.
      */
 
-    if (fillColor != NULL) {
+    if (rectOvalPtr->fillColor != NULL) {
 	Tcl_AppendResult(interp, pathCmd, (char *) NULL);
-	if (Tk_CanvasPsColor(interp, canvas, fillColor)
+	if (Tk_CanvasPsColor(interp, canvas, rectOvalPtr->fillColor)
 		!= TCL_OK) {
 	    return TCL_ERROR;
 	}
-	if (fillStipple != None) {
+	if (rectOvalPtr->fillStipple != None) {
 	    Tcl_AppendResult(interp, "clip ", (char *) NULL);
-	    if (Tk_CanvasPsStipple(interp, canvas, fillStipple)
+	    if (Tk_CanvasPsStipple(interp, canvas, rectOvalPtr->fillStipple)
 		    != TCL_OK) {
 		return TCL_ERROR;
 	    }
-	    if (color != NULL) {
+	    if (rectOvalPtr->outlineColor != NULL) {
 		Tcl_AppendResult(interp, "grestore gsave\n", (char *) NULL);
 	    }
 	} else {
@@ -1456,13 +1012,16 @@ RectOvalToPostscript(interp, canvas, itemPtr, prepass)
      * Now draw the outline, if there is one.
      */
 
-    if (color != NULL) {
-	Tcl_AppendResult(interp, pathCmd, "0 setlinejoin 2 setlinecap\n",
-		(char *) NULL);
-	if (Tk_CanvasPsOutline(canvas, itemPtr,
-		&(rectOvalPtr->outline))!= TCL_OK) {
+    if (rectOvalPtr->outlineColor != NULL) {
+	Tcl_AppendResult(interp, pathCmd, (char *) NULL);
+	sprintf(string, "%d setlinewidth", rectOvalPtr->width);
+	Tcl_AppendResult(interp, string,
+		" 0 setlinejoin 2 setlinecap\n", (char *) NULL);
+	if (Tk_CanvasPsColor(interp, canvas, rectOvalPtr->outlineColor)
+		!= TCL_OK) {
 	    return TCL_ERROR;
 	}
+	Tcl_AppendResult(interp, "stroke\n", (char *) NULL);
     }
     return TCL_OK;
 }
