@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkText.h 1.44 96/02/15 18:51:31
+ * SCCS: @(#) tkText.h 1.46 96/11/25 11:26:12
  */
 
 #ifndef _TKTEXT
@@ -106,6 +106,35 @@ typedef struct TkTextEmbWindow {
 					 * recently. */
 } TkTextEmbWindow;
 
+/*
+ * A structure of the following type holds information for each image
+ * embedded in a text widget.  This information is only used by the
+ * file tkTextImage.c
+ */
+
+typedef struct TkTextEmbImage {
+    struct TkText *textPtr;		/* Information about the overall text
+					 * widget. */
+    TkTextLine *linePtr;		/* Line structure that contains this
+					 * image. */
+    char *imageString;			/* Name of the image for this segment */
+    char *imageName;			/* Name used by text widget to identify
+    					 * this image.  May be unique-ified */
+    char *name;				/* Name used in the hash table.
+    					 * used by "image names" to identify
+    					 * this instance of the image */
+    Tk_Image image;			/* Image for this segment.  NULL
+					 * means that the image hasn't
+					 * been created yet. */
+    int align;				/* How to align image in vertical
+					 * space.  See definitions in
+					 * tkTextImage.c. */
+    int padX, padY;			/* Padding to leave around each side
+					 * of image, in pixels. */
+    int chunkCount;			/* Number of display chunks that
+					 * refer to this image. */
+} TkTextEmbImage;
+
 /*
  * The data structure below defines line segments.
  */
@@ -125,6 +154,8 @@ typedef struct TkTextSegment {
 	TkTextMark mark;		/* Information about mark. */
 	TkTextEmbWindow ew;		/* Information about embedded
 					 * window. */
+	TkTextEmbImage ei;		/* Information about embedded
+					 * image. */
     } body;
 } TkTextSegment;
 
@@ -271,7 +302,7 @@ typedef struct TkTextTag {
 				 * means no value specified here. */
     XColor *fgColor;		/* Foreground color for text.  NULL means
 				 * no value specified here. */
-    XFontStruct *fontPtr;	/* Font for displaying text.  NULL means
+    Tk_Font tkfont;		/* Font for displaying text.  NULL means
 				 * no value specified here. */
     Pixmap fgStipple;		/* Stipple bitmap for text and other
 				 * foreground stuff.   None means no value
@@ -335,6 +366,10 @@ typedef struct TkTextTag {
 				 * Must be tkTextCharUid, tkTextNoneUid,
 				 * tkTextWordUid, or NULL to use wrapMode
 				 * for whole widget. */
+    Arg elideString;		/* -elide option string (malloc-ed).
+				 * NULL means option not specified. */
+    int elide;		/* Non-zero means text is elided.
+				 * Only valid if elideString is non-NULL. */
     int affectsDisplay;		/* Non-zero means that this tag affects the
 				 * way information is displayed on the screen
 				 * (so need to redisplay if tag changes). */
@@ -431,6 +466,11 @@ typedef struct TkText {
 				 * window segment doesn't yet have an
 				 * associated window, there is no entry for
 				 * it here. */
+    Tcl_HashTable imageTable;	/* Hash table that maps from image names
+				 * to pointers to image segments.  If an
+				 * image segment doesn't yet have an
+				 * associated image, there is no entry for
+				 * it here. */
     Tk_Uid state;		/* Normal or disabled.  Text is read-only
 				 * when disabled. */
 
@@ -455,7 +495,7 @@ typedef struct TkText {
     XColor *highlightColorPtr;	/* Color for drawing traversal highlight. */
     Tk_Cursor cursor;		/* Current cursor for window, or None. */
     XColor *fgColor;		/* Default foreground color for text. */
-    XFontStruct *fontPtr;	/* Default font for displaying text. */
+    Tk_Font tkfont;		/* Default font for displaying text. */
     int charWidth;		/* Width of average character in default
 				 * font. */
     int spacing1;		/* Default extra spacing above first display
@@ -762,6 +802,8 @@ extern void		TkTextLostSelection _ANSI_ARGS_((
 extern TkTextIndex *	TkTextMakeIndex _ANSI_ARGS_((TkTextBTree tree,
 			    int lineIndex, int charIndex,
 			    TkTextIndex *indexPtr));
+extern int		TkTextIsElided _ANSI_ARGS_((TkText *textPtr,
+			    TkTextIndex *indexPtr));
 extern int		TkTextMarkCmd _ANSI_ARGS_((TkText *textPtr,
 			    Tcl_Interp *interp, int argc, char **argv));
 extern int		TkTextMarkNameToIndex _ANSI_ARGS_((TkText *textPtr,
@@ -793,6 +835,10 @@ extern void		TkTextSetYView _ANSI_ARGS_((TkText *textPtr,
 			    TkTextIndex *indexPtr, int pickPlace));
 extern int		TkTextTagCmd _ANSI_ARGS_((TkText *textPtr,
 			    Tcl_Interp *interp, int argc, char **argv));
+extern int		TkTextImageCmd _ANSI_ARGS_((TkText *textPtr,
+			    Tcl_Interp *interp, int argc, char **argv));
+extern int		TkTextImageIndex _ANSI_ARGS_((TkText *textPtr,
+			    char *name, TkTextIndex *indexPtr));
 extern int		TkTextWindowCmd _ANSI_ARGS_((TkText *textPtr,
 			    Tcl_Interp *interp, int argc, char **argv));
 extern int		TkTextWindowIndex _ANSI_ARGS_((TkText *textPtr,
