@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclIOCmd.c,v 1.4 1999/02/02 22:25:42 stanton Exp $
+ * SCCS: @(#) tclIOCmd.c 1.119 97/07/25 20:49:23
  */
 
 #include	"tclInt.h"
@@ -949,7 +949,7 @@ Tcl_FblockedObjCmd(unused, interp, objc, objv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_OpenObjCmd --
+ * Tcl_OpenCmd --
  *
  *	This procedure is invoked to process the "open" Tcl command.
  *	See the user documentation for details on what it does.
@@ -965,35 +965,35 @@ Tcl_FblockedObjCmd(unused, interp, objc, objv)
 
 	/* ARGSUSED */
 int
-Tcl_OpenObjCmd(notUsed, interp, argc, objv)
+Tcl_OpenCmd(notUsed, interp, argc, argv)
     ClientData notUsed;			/* Not used. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    Tcl_Obj * CONST objv[];		/* Argument objects. */
+    char **argv;			/* Argument strings. */
 {
     int pipeline, prot;
-    char *modeString, *arg1;
+    char *modeString;
     Tcl_Channel chan;
 
     if ((argc < 2) || (argc > 4)) {
-	Tcl_WrongNumArgs(interp, 1, objv, "fileName ?access? ?permissions?");
+	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
+		" fileName ?access? ?permissions?\"", (char *) NULL);
 	return TCL_ERROR;
     }
     prot = 0666;
     if (argc == 2) {
 	modeString = "r";
     } else {
-	modeString = Tcl_GetStringFromObj(objv[2], NULL);
+	modeString = argv[2];
 	if (argc == 4) {
-	    if (Tcl_GetIntFromObj(interp, objv[3], &prot) != TCL_OK) {
+	    if (Tcl_GetInt(interp, argv[3], &prot) != TCL_OK) {
 		return TCL_ERROR;
 	    }
 	}
     }
 
-    arg1 = Tcl_GetStringFromObj(objv[1], NULL);
     pipeline = 0;
-    if (arg1[0] == '|') {
+    if (argv[1][0] == '|') {
 	pipeline = 1;
     }
 
@@ -1002,10 +1002,10 @@ Tcl_OpenObjCmd(notUsed, interp, argc, objv)
      */
 
     if (!pipeline) {
-        chan = Tcl_OpenFileChannel(interp, arg1, modeString, prot);
+        chan = Tcl_OpenFileChannel(interp, argv[1], modeString, prot);
     } else {
 #ifdef MAC_TCL
-	Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+	Tcl_AppendResult(interp,
 		"command pipelines not supported on Macintosh OS",
 		(char *)NULL);
 	return TCL_ERROR;
@@ -1013,7 +1013,7 @@ Tcl_OpenObjCmd(notUsed, interp, argc, objv)
 	int mode, seekFlag, cmdArgc;
 	char **cmdArgv;
 
-	if (Tcl_SplitList(interp, arg1+1, &cmdArgc, &cmdArgv) != TCL_OK) {
+        if (Tcl_SplitList(interp, argv[1]+1, &cmdArgc, &cmdArgv) != TCL_OK) {
             return TCL_ERROR;
         }
 
@@ -1045,8 +1045,7 @@ Tcl_OpenObjCmd(notUsed, interp, argc, objv)
         return TCL_ERROR;
     }
     Tcl_RegisterChannel(interp, chan);
-    Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-	Tcl_GetChannelName(chan), (char *) NULL);
+    Tcl_AppendResult(interp, Tcl_GetChannelName(chan), (char *) NULL);
     return TCL_OK;
 }
 
