@@ -27,6 +27,7 @@ typedef struct Lang_CmdInfo
   Tcl_Interp  *interp;
   Tk_Window   tkwin;
   SV          *image; 
+  Tk_Font     tkfont;
  } Lang_CmdInfo;
 
 #ifdef WIN32
@@ -48,8 +49,8 @@ TkglueVtab *TkglueVptr
 #ifdef WIN32
 #define IMPORT_WIN32_VTABLES                                                   \
 do {                                                                           \
-  TkwinVptr     =   (TkwinVtab *) SvIV(perl_get_sv("Tk::TkwinVtab",5));        \
-  TkwinintVptr  =   (TkwinintVtab *) SvIV(perl_get_sv("Tk::TkwinintVtab",5));  \
+  TkwinVptr     =   (TkwinVtab *) SvIV(perl_get_sv("Tk::TkwinVtab",GV_ADDWARN|GV_ADD));        \
+  TkwinintVptr  =   (TkwinintVtab *) SvIV(perl_get_sv("Tk::TkwinintVtab",GV_ADDWARN|GV_ADD));  \
  } while (0);
 #else
 #define IMPORT_WIN32_VTABLES
@@ -57,14 +58,16 @@ do {                                                                           \
 
 #define IMPORT_VTABLES                                                         \
 do {                                                                           \
-  TkoptionVptr   =   (TkoptionVtab *) SvIV(perl_get_sv("Tk::TkoptionVtab",5)); \
-  LangVptr   =   (LangVtab *) SvIV(perl_get_sv("Tk::LangVtab",5));             \
-  TkVptr     =     (TkVtab *) SvIV(perl_get_sv("Tk::TkVtab",5));               \
-  TkintVptr  =  (TkintVtab *) SvIV(perl_get_sv("Tk::TkintVtab",5));            \
-  TkglueVptr = (TkglueVtab *) SvIV(perl_get_sv("Tk::TkglueVtab",5));           \
-  XlibVptr   =   (XlibVtab *) SvIV(perl_get_sv("Tk::XlibVtab",5));             \
+  TkoptionVptr   =   (TkoptionVtab *) SvIV(perl_get_sv("Tk::TkoptionVtab",GV_ADDWARN|GV_ADD)); \
+  LangVptr   =   (LangVtab *) SvIV(perl_get_sv("Tk::LangVtab",GV_ADDWARN|GV_ADD));             \
+  TkVptr     =     (TkVtab *) SvIV(perl_get_sv("Tk::TkVtab",GV_ADDWARN|GV_ADD));               \
+  TkintVptr  =  (TkintVtab *) SvIV(perl_get_sv("Tk::TkintVtab",GV_ADDWARN|GV_ADD));            \
+  TkglueVptr = (TkglueVtab *) SvIV(perl_get_sv("Tk::TkglueVtab",GV_ADDWARN|GV_ADD));           \
+  XlibVptr   =   (XlibVtab *) SvIV(perl_get_sv("Tk::XlibVtab",GV_ADDWARN|GV_ADD));             \
  } while (0)
 
+#define VTABLE_INIT() IMPORT_VTABLES
+
 extern Lang_CmdInfo *WindowCommand _ANSI_ARGS_((SV *win,HV **hptr, int moan));
 extern Tk_Window SVtoWindow _ANSI_ARGS_((SV *win));
 extern Tk_Font SVtoFont _ANSI_ARGS_((SV *win));
@@ -75,10 +78,12 @@ extern SV *TkToWidget _ANSI_ARGS_((Tk_Window tkwin,Tcl_Interp **pinterp));
 extern SV *FindTkVarName _ANSI_ARGS_((char *varName,int flags));
 extern void EnterWidgetMethods _ANSI_ARGS_((char *package, ...));
 extern SV *MakeReference _ANSI_ARGS_((SV * sv));
-extern void Lang_TkCommand _ANSI_ARGS_ ((char *name, Tcl_CmdProc *proc));
 extern Tk_Window TkToMainWindow _ANSI_ARGS_((Tk_Window tkwin));
+extern void Lang_TkSubCommand _ANSI_ARGS_ ((char *name, Tcl_CmdProc *proc));
+extern void Lang_TkCommand _ANSI_ARGS_ ((char *name, Tcl_CmdProc *proc));
 extern SV *XEvent_Info _((EventAndKeySym *obj,char *s));
 extern EventAndKeySym *SVtoEventAndKeySym _((SV *arg));
+extern int XSTkCommand _ANSI_ARGS_((CV *cv, Tcl_CmdProc *proc, int items, SV **args));
 
 extern XS(XStoWidget);
 
@@ -89,6 +94,12 @@ EXTERN void  Boot_Glue _ANSI_ARGS_((void));
 EXTERN void  Boot_Tix  _ANSI_ARGS_((void));
 EXTERN void install_vtab _((char *name, void *table, size_t size));
 extern SV *TagIt _((SV *sv, char *type));
+extern void Font_DESTROY _((SV *sv));
 
 
+#ifndef WIN32
+#define HWND void *
+#endif
+EXTERN HWND SVtoHWND _ANSI_ARGS_((SV *win));
+
 #endif
