@@ -22,6 +22,10 @@
 #  define Lang_TkCommand (*TkglueVptr->V_Lang_TkCommand)
 #endif
 
+#ifndef Lang_TkSubCommand
+#  define Lang_TkSubCommand (*TkglueVptr->V_Lang_TkSubCommand)
+#endif
+
 #ifndef MakeReference
 #  define MakeReference (*TkglueVptr->V_MakeReference)
 #endif
@@ -30,6 +34,10 @@
 #  define SVtoFont (*TkglueVptr->V_SVtoFont)
 #endif
 
+#ifndef SVtoHWND
+#  define SVtoHWND (*TkglueVptr->V_SVtoHWND)
+#endif
+
 #ifndef SVtoWindow
 #  define SVtoWindow (*TkglueVptr->V_SVtoWindow)
 #endif
@@ -50,5 +58,9 @@
 #  define WindowCommand (*TkglueVptr->V_WindowCommand)
 #endif
 
+#ifndef XSTkCommand
+#  define XSTkCommand (*TkglueVptr->V_XSTkCommand)
+#endif
+
 #endif /* NO_VTABLES */
 #endif /* _TKGLUE_VM */
